Installation |pypi_version| |python_versions| |pypi_license|
============================================================

Easiest
~~~~~~~
Download the latest stable code from `PyPI <https://pypi.python.org/pypi/biokeen>`_ with:

.. code-block:: sh

   $ python3 -m pip install biokeen

Get the Latest
~~~~~~~~~~~~~~~
Download the most recent code from `GitHub <https://github.com/SmartDataAnalytics/BioKEEN>`_ with:

.. code-block:: sh

   $ python3 -m pip install git+https://github.com/SmartDataAnalytics/BioKEEN.git

.. |python_versions| image:: https://img.shields.io/pypi/pyversions/biokeen.svg
    :alt: Stable Supported Python Versions
.. |pypi_version| image:: https://img.shields.io/pypi/v/biokeen.svg
    :alt: Current version on PyPI
.. |pypi_license| image:: https://img.shields.io/pypi/l/biokeen.svg
    :alt: MIT License
